diff --git a/README.md b/README.md
index 60c4fec2dc..86cbb5c8d8 100644
--- a/README.md
+++ b/README.md
@@ -1,3 +1,21 @@
+# Color Scheme Change
+Tested & Working 1/26/2024 :white_check_mark:
+![image](https://github.com/EnziTheViking/PrettyWinUtil/assets/79238110/36221761-a7df-4a69-8bfd-167b08f6c392)
+
+![image](https://github.com/EnziTheViking/PrettyWinUtil/assets/79238110/a971c00a-4aa5-4045-a106-3bf7264ef98b)
+
+![image](https://github.com/EnziTheViking/PrettyWinUtil/assets/79238110/3f422f4c-9781-4411-b246-54c0707c500b)
+
+![image](https://github.com/EnziTheViking/PrettyWinUtil/assets/79238110/b599c6c5-42a7-45a1-ac39-1c8a4e27a781)
+
+![image](https://github.com/EnziTheViking/PrettyWinUtil/assets/79238110/dfcb1aa3-cf8e-4a4f-b87e-57917aedff86)
+
+
+---
+
+
+
+
# Chris Titus Tech's Windows Utility
This utility is a compilation of Windows tasks I perform on each Windows system I use. It is meant to streamline *installs*, debloat with *tweaks*, troubleshoot with *config*, and fix Windows *updates*. I am extremely picky about any contributions to keep this project clean and efficient.
diff --git a/config/themes.json b/config/themes.json
index fb23ca951f..9f5869fdfc 100644
--- a/config/themes.json
+++ b/config/themes.json
@@ -1,65 +1,95 @@
{
"Classic": {
- "ComboBoxBackgroundColor": "#FFFFFF",
- "LabelboxForegroundColor": "#000000",
- "MainForegroundColor": "#000000",
- "MainBackgroundColor": "#FFFFFF",
- "LabelBackgroundColor": "#FAFAFA",
- "LinkForegroundColor": "#000000",
- "LinkHoverForegroundColor": "#000000",
- "GroupBorderBackgroundColor": "#000000",
- "ComboBoxForegroundColor": "#000000",
- "ButtonInstallBackgroundColor": "#FFFFFF",
- "ButtonTweaksBackgroundColor": "#FFFFFF",
- "ButtonConfigBackgroundColor": "#FFFFFF",
- "ButtonUpdatesBackgroundColor": "#FFFFFF",
- "ButtonInstallForegroundColor": "#000000",
- "ButtonTweaksForegroundColor": "#000000",
- "ButtonConfigForegroundColor": "#000000",
- "ButtonUpdatesForegroundColor": "#000000",
- "ButtonBackgroundColor": "#F5F5F5",
- "ButtonBackgroundPressedColor": "#1A1A1A",
- "CheckboxMouseOverColor": "#999999",
- "ButtonBackgroundMouseoverColor": "#C2C2C2",
- "ButtonBackgroundSelectedColor": "#F0F0F0",
- "ButtonForegroundColor": "#000000",
- "ButtonBorderThickness": "1",
- "ButtonMargin": "1",
- "ButtonCornerRadius": "2",
- "ToggleButtonHeight": "25",
- "BorderColor": "#000000",
- "BorderOpacity": "0.2",
- "ShadowPulse": "Forever"
+ "ComboBoxForegroundColor": "#fcfcfd",
+ "ComboBoxBackgroundColor": "#1f72b5",
+ "LabelboxForegroundColor": "#fcfcfd",
+
+ "MainForegroundColor": "#fcfcfd",
+ "MainBackgroundColor": "#1f1f1f",
+
+ "LabelBackgroundColor": "#1f1f1f",
+ "LinkForegroundColor": "#1f72b5",
+ "LinkHoverForegroundColor": "#000000",
+ "GroupBorderBackgroundColor": "#000000",
+
+ "ButtonInstallBackgroundColor": "#1f72b5",
+ "ButtonTweaksBackgroundColor": "#1f72b5",
+ "ButtonConfigBackgroundColor": "#1f72b5",
+ "ButtonUpdatesBackgroundColor": "#1f72b5",
+
+ "ButtonInstallForegroundColor": "#fcfcfd",
+ "ButtonTweaksForegroundColor": "#fcfcfd",
+ "ButtonConfigForegroundColor": "#fcfcfd",
+ "ButtonUpdatesForegroundColor": "#fcfcfd",
+
+ "ButtonForegroundColor": "#fcfcfd",
+
+ "ButtonBackgroundMouseoverColor": "#144974",
+ "ButtonBackgroundSelectedColor": "#0d2e49",
+
+ "ButtonPage1BackgroundColor": "#1f72b5",
+ "ButtonBackgroundColor": "#000000",
+
+ "ButtonBackgroundPressedColor": "#1f72b5",
+
+ "CheckboxMouseOverColor": "#fcfcfd",
+
+ "ToggleOn": "#35b355",
+ "ToggleOff": "#ff5757",
+
+ "ButtonBorderThickness": "1",
+ "ButtonMargin": "1",
+ "ButtonCornerRadius": "2",
+ "ToggleButtonHeight": "25",
+ "BorderColor": "#000000",
+ "BorderOpacity": "0.0",
+ "ShadowPulse": "0:0:0"
},
"Matrix": {
- "ComboBoxBackgroundColor": "#000000",
- "LabelboxForegroundColor": "#FFEE58",
- "MainForegroundColor": "#9CCC65",
- "MainBackgroundColor": "#000000",
- "LabelBackgroundColor": "#000000",
- "LinkForegroundColor": "#add8e6",
- "LinkHoverForegroundColor": "#FFFFFF",
- "ComboBoxForegroundColor": "#FFEE58",
- "ButtonInstallBackgroundColor": "#222222",
- "ButtonTweaksBackgroundColor": "#333333",
- "ButtonConfigBackgroundColor": "#444444",
- "ButtonUpdatesBackgroundColor": "#555555",
- "ButtonInstallForegroundColor": "#FFFFFF",
- "ButtonTweaksForegroundColor": "#FFFFFF",
- "ButtonConfigForegroundColor": "#FFFFFF",
- "ButtonUpdatesForegroundColor": "#FFFFFF",
- "ButtonBackgroundColor": "#000019",
- "ButtonBackgroundPressedColor": "#FFFFFF",
- "ButtonBackgroundMouseoverColor": "#A55A64",
- "ButtonBackgroundSelectedColor": "#FF5733",
- "ButtonForegroundColor": "#9CCC65",
- "ButtonBorderThickness": "1",
- "ButtonMargin": "1",
- "ButtonCornerRadius": "2",
- "ToggleButtonHeight": "25",
- "BorderColor": "#FFAC1C",
- "BorderOpacity": "0.8",
- "ShadowPulse": "0:0:3"
+ "ComboBoxForegroundColor": "#fcfcfd",
+ "ComboBoxBackgroundColor": "#1f72b5",
+ "LabelboxForegroundColor": "#fcfcfd",
+
+ "MainForegroundColor": "#fcfcfd",
+ "MainBackgroundColor": "#1f1f1f",
+
+ "LabelBackgroundColor": "#1f1f1f",
+ "LinkForegroundColor": "#1f72b5",
+ "LinkHoverForegroundColor": "#000000",
+ "GroupBorderBackgroundColor": "#000000",
+
+ "ButtonInstallBackgroundColor": "#1f72b5",
+ "ButtonTweaksBackgroundColor": "#1f72b5",
+ "ButtonConfigBackgroundColor": "#1f72b5",
+ "ButtonUpdatesBackgroundColor": "#1f72b5",
+
+ "ButtonInstallForegroundColor": "#fcfcfd",
+ "ButtonTweaksForegroundColor": "#fcfcfd",
+ "ButtonConfigForegroundColor": "#fcfcfd",
+ "ButtonUpdatesForegroundColor": "#fcfcfd",
+
+ "ButtonForegroundColor": "#fcfcfd",
+
+ "ButtonBackgroundMouseoverColor": "#144974",
+ "ButtonBackgroundSelectedColor": "#0d2e49",
+
+ "ButtonPage1BackgroundColor": "#1f72b5",
+ "ButtonBackgroundColor": "#000000",
+
+ "ButtonBackgroundPressedColor": "#1f72b5",
+
+ "CheckboxMouseOverColor": "#fcfcfd",
+
+ "ToggleOn": "#35b355",
+ "ToggleOff": "#ff5757",
+
+ "ButtonBorderThickness": "1",
+ "ButtonMargin": "1",
+ "ButtonCornerRadius": "2",
+ "ToggleButtonHeight": "25",
+ "BorderColor": "#000000",
+ "BorderOpacity": "0.0",
+ "ShadowPulse": "0:0:0"
},
"Dark": {
"ComboBoxBackgroundColor": "#000000",
diff --git a/scripts/main.ps1 b/scripts/main.ps1
index 38007969b4..311c34166e 100644
--- a/scripts/main.ps1
+++ b/scripts/main.ps1
@@ -441,6 +441,11 @@ $sync["AboutMenuItem"].Add_Click({
$sync["SettingsPopup"].IsOpen = $false
# Example usage
$authorInfo = @"
+FORK : PrettyWinUtil
+Author : @EnziTheViking
+GitHub : https://github.com/EnziTheViking/PrettyWinUtil
+
+OG Software
Author : @christitustech
Runspace : @DeveloperDurp
GUI : @KonTy
@@ -448,7 +453,7 @@ MicroWin : @KonTy
GitHub : https://github.com/ChrisTitusTech/winutil
Version : $($sync.version)
"@
- Show-CustomDialog -Message $authorInfo -Width 400
+ Show-CustomDialog -Message $authorInfo -Width 400 -height 270
})
$sync["Form"].ShowDialog() | out-null
diff --git a/xaml/inputXML.xaml b/xaml/inputXML.xaml
index 9fee01b468..7bb0c93400 100644
--- a/xaml/inputXML.xaml
+++ b/xaml/inputXML.xaml
@@ -208,7 +208,7 @@
-
+
@@ -219,7 +219,7 @@
-
+
@@ -430,7 +430,7 @@
-
+
@@ -442,7 +442,7 @@
+ To="{ToggleOn}" Duration="0:0:0.1" />
+ To="{ToggleOff}" Duration="0:0:0.1" />
-
+
-
+
@@ -522,12 +522,12 @@
-
+ From="5" To="15" Duration="{ShadowPulse}" AutoReverse="True"/> -->
@@ -658,7 +658,7 @@
IsOpen="False"
PlacementTarget="{Binding ElementName=SettingsButton}" Placement="Bottom"
HorizontalAlignment="Right" VerticalAlignment="Top">
-
+
@@ -691,11 +691,11 @@
-
-
-
-
-
+
+
+
+
+
diff --git a/functions/private/Show-CustomDialog.ps1 b/functions/private/Show-CustomDialog.ps1
index e102c43e23..33070f2cbb 100644
--- a/functions/private/Show-CustomDialog.ps1
+++ b/functions/private/Show-CustomDialog.ps1
@@ -31,7 +31,7 @@ function Show-CustomDialog {
$foregroundColor = [Windows.Media.Brushes]::White
$backgroundColor = [Windows.Media.Brushes]::Black
$font = New-Object Windows.Media.FontFamily("Consolas")
- $borderColor = [Windows.Media.Brushes]::Green
+ $borderColor = [Windows.Media.Brushes]::White
$buttonBackgroundColor = [Windows.Media.Brushes]::Black
$buttonForegroundColor = [Windows.Media.Brushes]::White
$shadowColor = [Windows.Media.ColorConverter]::ConvertFromString("#AAAAAAAA")
@@ -49,7 +49,7 @@ function Show-CustomDialog {
$dialog.Background = $backgroundColor
$dialog.FontFamily = $font
# Create a Border for the green edge with rounded corners
$border = New-Object Windows.Controls.Border
$border.BorderBrush = $borderColor
$border.BorderThickness = New-Object Windows.Thickness(1) # Adjust border thickness as needed
@@ -49,7 +49,7 @@ function Show-CustomDialog {
$dialog.Background = $backgroundColor
$dialog.FontFamily = $font
- # Create a Border for the green edge with rounded corners
+ # Create a Border for the White edge with rounded corners
$border = New-Object Windows.Controls.Border
$border.BorderBrush = $borderColor